# Credits

This project origin is https://github.com/white-seolpyo/seolpyo-mplchart  
I have adopted it for users from Europe and other english speaking regions  
Glyphs have been removed so you don't need to deal with fonts stuff

# Document
[English Document](https://white.seolpyo.com/entry/148/)

[한글 설명서](https://white.seolpyo.com/entry/147/)


# Sample Image
## sample
![sample gif](https://raw.githubusercontent.com/white-seolpyo/seolpyo-mplchart/refs/heads/main/images/sample.gif)

## tkinter sample
![tkinter sample gif](https://raw.githubusercontent.com/white-seolpyo/seolpyo-mplchart/refs/heads/main/images/with%20tkinter.gif)

## English format sample
![english sample](https://raw.githubusercontent.com/white-seolpyo/seolpyo-mplchart/refs/heads/main/images/change%20color.png)

## Korean format sample
![korean sample](https://raw.githubusercontent.com/white-seolpyo/seolpyo-mplchart/refs/heads/main/images/sample%20kor.png)


# 40,000 data sample
![40,000 sample](https://raw.githubusercontent.com/white-seolpyo/seolpyo-mplchart/refs/heads/main/images/40000.gif)
